@@ -3,6 +3,7 @@ from faraday_agent_parameters_types.custom_types import (
     faraday_string,
     faraday_boolean,
     faraday_list,
+    faraday_domains_list,
     faraday_int_range,
     faraday_ip,
     faraday_float,
@@ -14,6 +15,7 @@ DATA_TYPE = {
     "string": faraday_string.FaradayStringSchema(),
     "boolean": faraday_boolean.FaradayBooleanSchema(),
     "list": faraday_list.FaradayListSchema(),
+    "domains": faraday_domains_list.FaradayDomainsListSchema(),
     "range": faraday_int_range.FaradayRangeSchema(),
     "ip": faraday_ip.FaradayIPSchema(),
     "float": faraday_float.FaradayFloatSchema(),
